local overrides = require("custom.configs.overrides")

---@type NvPluginSpec[]
local plugins = {

  -- Override plugin definition options

  {
    "christoomey/vim-tmux-navigator",
    lazy = false,
  },

  {
    "neovim/nvim-lspconfig",
    dependencies = {
      -- format & linting
      {
        "jose-elias-alvarez/null-ls.nvim",
        config = function()
          require "custom.configs.null-ls"
        end,
      },
    },
    config = function()
      require "plugins.configs.lspconfig"
      require "custom.configs.lspconfig"
    end, -- Override to setup mason-lspconfig
  },

  {
    "kylechui/nvim-surround",
    version = "*", -- Use for stability; omit to use `main` branch for the latest features
    event = "VeryLazy",
    config = function()
        require("nvim-surround").setup({
            -- Configuration here, or leave empty to use defaults
        })
    end
  },

  -- {
  --   "cormacrelf/dark-notify",
  --   opts = {
  --     onchange = function(mode)
  --     -- optional, you can configure your own things to react to changes.
  --     -- this is called at startup and every time dark mode is switched,
  --     -- either via the OS, or because you manually set/toggled the mode.
  --     -- mode is either "light" or "dark"
  --     end,
  --   }
  -- },

  -- override plugin configs
  {
    "williamboman/mason.nvim",
    opts = {
      ensure_installed = {
        -- python
        "black",
        "pyright",
        "ruff-lsp",

        -- web
        "typescript-language-server",
        "eslint-lsp",
        -- "eslint-vue-plugin",
        "vls",
        "prettierd",

        "gopls",
        "grammarly-languageserver",
        "emmet-ls",
        "lua-language-server",
        -- "tailwindcss-language-server",
      },
    },
  },

  {
    "nvim-treesitter/nvim-treesitter",
     opts = {
      ensure_installed = {
        -- defaults 
        "vim",
        "lua",

        -- misc
        "python",
        "dockerfile",
        "bash",
        "csv",
        "diff",
        "git_config",
        "git_rebase",
        "gitcommit",
        "gitignore",
        "markdown",
        "markdown_inline",
        "ruby",
        "sql",
        "ssh_config",
        "toml",

        -- mobile
        "kotlin",

        -- web dev 
        "twig",
        "scss",
        "php",
        "prisma",
        "pug",
        "htmldjango",
        "html",
        "css",
        "javascript",
        "typescript",
        "tsx",
        "json",
        "vue",
        "svelte",

        -- low level
        "c",
        "cpp",
        "go",
        "rust",
      },
    },
  },

  {
    "nvim-tree/nvim-tree.lua",
    opts = overrides.nvimtree,
  },

  -- Install a plugin
  {
    "max397574/better-escape.nvim",
    event = "InsertEnter",
    config = function()
      require("better_escape").setup()
    end,
  },

  {
    "hrsh7th/nvim-cmp",
    opts = {
      sources = {
        { name = "nvim_lsp" },
        { name = "luasnip" },
        { name = "buffer" },
        { name = "nvim_lua" },
        { name = "path" },
        { name = "cmp_tabnine" },
      },
    },

    dependencies = {
      {
        "tzachar/cmp-tabnine",
        build = "./install.sh",
        config = function()
          local tabnine = require "cmp_tabnine.config"
          tabnine:setup {} -- put your options here
        end,
      },
    },
},


  -- To make a plugin not be loaded
  -- {
  --   "NvChad/nvim-colorizer.lua",
  --   enabled = false
  -- },

  -- All NvChad plugins are lazy-loaded by default
  -- For a plugin to be loaded, you will need to set either `ft`, `cmd`, `keys`, `event`, or set `lazy = false`
  -- If you want a plugin to load on startup, add `lazy = false` to a plugin spec, for example
  -- {
  --   "mg979/vim-visual-multi",
  --   lazy = false,
  -- }
}

return plugins

